##  Implications of Meta Model v4 on IT Components in the Catalog
Items in the catalog have been updated to reflect the new subtypes (SaaS, PaaS, IaaS) introduced with meta model v4. As a result, many of the catalog items previously categorized as 'Software,' 'Hardware,' or 'Service' now fall under one of the three 'as a service' types.
Your existing or new fact sheets linked to catalog items will maintain their current subtype classification until the subtypes SaaS, PaaS, and IaaS are introduced in your workspace. Once introduced, the relevant fact sheets will automatically transition into the new subtypes whenever a catalog item is refreshed with updates.
To update all fact sheets at once after aligning your workspace with meta model v4, you can raise a support ticket at [SAP LeanIX Support![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fsupport "https://www.leanix.net/support"). If you're an SAP customer, submit a request from the [SAP for Me![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fme.sap.com%2F "https://me.sap.com/") portal.
